@@ -1,10 +1,10 @@
 #!/usr/bin/env python
-# Time-stamp: <2002-01-23 19:32:21 crabbkw>
-# Code and design by Casey Crabb (crabbkw@rose-hulman.edu)
+# Time-stamp: <2003-04-02 22:35:03 crabbkw>
+# Code and design by Casey Crabb (crabbkw@nafai.dyndns.org)
 # This code is licensed under the BSD license.
 # See the LICENSE file for details
 #
-# Copyright Casey Crabb (crabbkw@rose-hulman.edu) July 2001
+# Copyright Casey Crabb (crabbkw@nafai.dyndns.org) July 2001
 #
 
 # from __future__ import nested_scopes
@@ -58,12 +58,13 @@ white = chr(27)+"[37;1m"
 # some people use buffering for performance - we use it to lie :-)
 #
 class FileWrapper:
-    def __init__(self,file):
+    def __init__(self,file,encoding):
         self.file = file
         self.topSent = 0
         self.eof = 0
         self.leftover = "<top>\n"
         self.context = ""
+        self.encoding = encoding
 
     def read(self,bytes):
         if self.eof:
@@ -77,6 +78,7 @@ class FileWrapper:
         if( len( self.leftover ) >= bytes ):
             out = self.leftover[:bytes]
             self.leftover = self.leftover[bytes:]
+            out = out.encode(self.encoding)
             return out
 
         #
@@ -141,10 +143,10 @@ class FileWrapper:
         #
         if ( out != "" ):
             self.context = out[-1:]
-        #print out
 
+        out = out.encode(self.encoding)
         return out
-            
+
 def getTerminalWidth():
     terminalWidth = 80 #linelength
 
@@ -199,7 +201,7 @@ class LogHandler:
         # saves me a bit of coding complexity
         # we'll see if this has to be fixed later....
         self.profile = profile
-        self.colors = self.profile.colors.sessioncolors
+        self.colors = self.profile.sessioncolors
 
     def readLogs( self, nick, mintime, maxtime, content, maxmessages, interactive ):
         if( interactive and ( mintime == None ) and ( maxtime == None ) and \
@@ -355,6 +357,11 @@ class LogHandler:
         #
         # get a directory listing of the log dir...
         #
+        try:
+          os.makedirs(self.profile.logdir,0700)
+        except:
+          pass
+
         dir = os.listdir( self.profile.logdir )
 
         nickstmp = string.split( self.nick, "," )
@@ -387,14 +394,18 @@ class LogHandler:
         for n in nicks:
             try:
                 self.messages = []
-                f = open( self.profile.logdir + "/" + self.getJID( n ), "r")
+                #f = codecs.open( self.profile.logdir + "/" + self.getJID( n ), "r", self.profile.encoding, 'replace')
+                fileToOpen = self.profile.logdir + "/" + self.getJID( n )
+                #print "fileToOpen isinstance(unicode): ", isinstance(fileToOpen, unicode)
+                fileToOpen = fileToOpen.encode(self.profile.encoding)
+                f = codecs.open( fileToOpen, "r", self.profile.encoding)
                 self.current_log = self.getJID( n )
-                filewrapper = FileWrapper(f)
+                filewrapper = FileWrapper(f, self.profile.encoding)
     
                 #
                 # have to init a different parser for each doc.
                 #
-                parser = expat.ParserCreate( "ISO-8859-1" )
+                parser = expat.ParserCreate( self.profile.encoding )
                 parser.StartElementHandler = self.startElement
                 parser.EndElementHandler = self.endElement
                 parser.CharacterDataHandler = self.characters
@@ -685,7 +696,7 @@ class LogHandler:
 
     def setProfile( self, profile ):
         self.profile = profile
-        self.colors = self.profile.colors.sessioncolors
+        self.colors = self.profile.sessioncolors
 
     def getNick(self, jid):
         if self.standalone:
